import { useEffect, useRef, useState } from 'react';
export function use_rerender() {
    const set_state = useState({})[1];
    return function rerender() {
        set_state({});
    };
}
export function use_modal() {
    const [visible, set_visible] = useState(false);
    return {
        visible,
        open() {
            set_visible(true);
        },
        close() {
            set_visible(false);
        }
    };
}
/** 类似 useState, 同时将 state 绑定到 ref 从而方便的获取其最新的值, 返回 [state, ref, set_state] */
export function use_ref_state(initial_state) {
    let [state, _set_state] = useState(initial_state);
    let ref = useRef(state);
    return [state, ref, (value) => { _set_state(ref.current = value); }];
}
/** 根据 html element 渲染的高度更新 height state */
export function use_height(initial_height) {
    let [height, set_height] = useState(initial_height);
    let ref = useRef(undefined);
    useEffect(() => {
        if (ref.current)
            set_height(ref.current.clientHeight);
    }, [ref.current]);
    return [height, ref];
}
//# sourceMappingURL=hooks.js.map